@@ -19,28 +19,16 @@ Chart::Clicker::Decoration
 =head1 DESCRIPTION
 
 Chart::Clicker::Decoration is a straight subclass of
-L<Chart::Clicker::Drawing::Component>.
+L<Graphics::Primitive::Canvas>.
 
 =head1 SYNOPSIS
 
 =head1 METHODS
 
-=head2 Constructor
-
-=over 4
-
-=item I<new>
+=head2 new
 
 Creates a new Chart::Clicker::Decoration
 
-=back
-
-=head2 Instance Methods
-
-=over 4
-
-=back
-
 =head1 AUTHOR
 
 Cory 'G' Watson <gphat@cpan.org>
